# Supplementary materials

This directory contains the input data, simulation code, and analysis scripts,
to reproduce all of the results from the manuscript "Accounting for
healthcare-seeking behaviours and testing practices in real-time influenza
forecasts".

This manuscript was initially made available as a
[bioRxiv pre-print](https://doi.org/10.1101/475756).

**Important:** note that all of the simulation results are included here, so
there is no need to re-run the forecast simulations in order to generate the
results presented in the manuscript. This is because the forecast simulations
can take several hours (or longer) to run.

## License

The code is distributed under the terms of the BSD 3-Clause license (see the
file `LICENSE` for the license text), all other materials are distributed
under the terms of the [Creative Commons Attribution License](http://creativecommons.org/licenses/by/4.0/).

## Software requirements

To run the influenza forecasts you will need a working installation of
[Python](https://www.python.org/) (version 2.7 or 3.5+, we used version 3.6.3)
and the following packages:

- epifx 0.5.6
- pypfilt 0.5.4

These packages, and their dependencies, can be installed by running:

    pip install -r adjusted-forecasts/requirements.txt

You may want to run this command from within a
[virtual environment](https://docs.python-guide.org/dev/virtualenvs/).
The script `adjusted-forecasts/create_venv.sh` is provided as an example.

To produce the figures included in the manuscript, you will need a working
installation of [R](https://www.r-project.org/) (we used version 3.5.1) and
the following packages:

- Cairo 1.5-9
- ggplot2 3.1.0
- rhdf5 2.24.0
- scales 1.0.0
- viridisLite 0.3.0

Most of these can be installed from within R using `install.packages`.
The installation process is a little different for
[rhdf5](https://www.bioconductor.org/packages/release/bioc/html/rhdf5.html).

## Flutracking survey data

The weekly survey data are located in `flutracking-estimation/data`.

The script `flutracking-estimation/evolve-posteriors.R` will generate the
weekly posterior distributions for each influenza season, and write the
results to `flutracking-estimation/posteriors.ssv`.

## Influenza surveillance data

The surveillance data for each city are located in `surveillance-data`.

## Influenza forecasts

The script `adjusted-forecasts/run_forecasts.py` will run the influenza
forecast simulations, **which may take a number of hours to complete**.
For this reason, it is best to run these simulations across multiple cores:

    cd adjusted-forecasts
    ./run_forecasts.py --spawn 16

This will create many HDF5 files in `adjusted-forecasts/output`.

### Extracting key forecast outputs

The script `adjusted-forecasts/collect-results.R` will extract key outputs
(such as the forecast performance and calibrated identification probability)
and write these data to:

- `adjusted-forecasts/bayes-factors.ssv`
- `adjusted-forecasts/pr-obs.ssv`

The script `adjusted-forecasts/collect-forecast-data.R` will extract forecast
credible intervals and available observations for each forecast, and write
these data to:

- `adjusted-forecasts/forecast-cis.ssv`
- `adjusted-forecasts/forecast-obs.ssv`

## Creating the manuscript figures

Each of the manuscript figures are provided here as PDF files.

You can re-plot each figure by running the associated plotting script:

- `Rscript plot-figure-1.R`
- `Rscript plot-figure-2.R`
- `Rscript plot-figure-3a.R`
- `Rscript plot-figure-3b.R`
- `Rscript plot-figure-4.R`
- `Rscript plot-figure-5.R`
- `Rscript plot-figure-6.R`
- `Rscript plot-figure-7.R`
- `Rscript plot-figure-8.R`

If you have the [make] build automation tool installed, you can re-generate
each figure by running:

    make

This will only update figures if the plotting script or source data have been
modified, or if the figure itself has been deleted.

You can delete all of the figures and force them to be re-created by running:

    make distclean
    make
