#!/usr/bin/Rscript --vanilla

##
## Used to detect whether this script is being run from the command-line.
##
SCRIPT <- 'estimate-bg.R'


##
## The script entry point.
##
main <- function(args = NULL) {
    data_dir <- file.path('..', 'surveillance-data')
    data_files <- c(
        'brisbane' = 'qld-brisbane-weekly-notifications.ssv',
        'melbourne' = 'vdh-byweek-counts.ssv',
        'perth' = 'wa-pathwest-counts.ssv',
        'sydney' = 'sydney-weekly-notifications.ssv')

    ## Estimate background rates using the data for April and May.
    incl_months <- 4:5

    for (locn in names(data_files)) {
        df <- read.table(file.path(data_dir, data_files[locn]),
                         header = TRUE, as.is = TRUE)
        df <- df[df$year %in% 2014:2017, ]

        if ('to' %in% names(df)) {
            df$date <- as.Date(df$to)
        } else {
            df$date <- as.Date(df$week)
        }
        df$month <- as.numeric(format(df$date, '%m'))
        df <- df[df$month %in% incl_months, ]

        df_mean <- aggregate(count ~ year, data = df, FUN = mean)
        df_varn <- aggregate(count ~ year, data = df, FUN = var)
        df_mean$bg_obs <- round(df_mean$count)
        df_mean$count <- NULL
        df_varn$bg_var <- round(df_varn$count)
        df_varn$count <- NULL
        df_mean$locn <- locn

        cat(locn, '\n')
        cat('\'bg_obs\': {')
        for (i in 1:nrow(df_mean)) {
            cat(df_mean$year[i], ': ', df_mean$bg_obs[i], sep = '')
            if (i < nrow(df_mean)) {
                cat(', ')
            }
        }
        cat('},\n')
        cat('\'bg_var\': {')
        for (i in 1:nrow(df_varn)) {
            cat(df_varn$year[i], ': ', df_varn$bg_var[i], sep = '')
            if (i < nrow(df_varn)) {
                cat(', ')
            }
        }
        cat('},\n')
    }

    return(0)
}


##
## Only call main() if this script is being run from the command-line.
##
if (! interactive()) {
    file.arg <- grep('^--file=', commandArgs(FALSE), value = TRUE)
    file.path <- substring(file.arg, 8)
    file.regex <- paste0('^(|.*/)', SCRIPT)
    if (grepl(file.regex, file.path)) {
        quit(status = main(args = commandArgs(TRUE)))
    }
}
