#!/bin/sh
##
## Set the PDF creation date to a fixed timestamp.
## This ensures that commits only capture meaningful changes to PDF files.
##

if ! which pdftk > /dev/null 2>&1; then
    echo "WARNING: pdftk not found, will not fix PDF metadata"
    exit 0
fi

if [ "$#" -ne 1 ]; then
    echo "USAGE: $(basename "${0}") filename.pdf"
    exit 2
fi

if [ ! -f "$1" ]; then
    echo "ERROR: file ${1} does not exist"
    exit 2
fi

PDF_FILE="$1"
PDF_TMP="${PDF_FILE}.tmp"
META_OLD=".metadata.old"
META_NEW=".metadata.new"

(   # Extract the current metadata.
    pdftk "${PDF_FILE}" dump_data output "${META_OLD}"
    # Reset every timestamp to a fixed value.
    sed 's/^InfoValue: D:.*/InfoValue: D:20180101000000+10\&apos;00/' "${META_OLD}" > "${META_NEW}"
    # Update the metadata.
    pdftk "${PDF_FILE}" update_info "${META_NEW}" output "${PDF_TMP}"
    # Remove the metadata files.
    rm "${META_OLD}" "${META_NEW}"
    # Replace the existing PDF file.
    mv "${PDF_TMP}" "${PDF_FILE}")
