#!/usr/bin/Rscript --vanilla

##
## Used to detect whether this script is being run from the command-line.
##
SCRIPT <- 'plot-figure-1.R'


##
## The script entry point.
##
main <- function(args = NULL) {
    library(ggplot2)
    library(scales)
    library(Cairo)
    library(viridisLite)
    ## library(themergm)
    source('theme_rgm.R')

    data_file <- 'flutracking-estimation/posteriors.ssv'
    plot_file <- 'figure-1.pdf'

    ## Plot dimensions (in inches).
    plot_w <- 8
    plot_h <- 5.5

    keep_states <- c('NSW', 'QLD', 'VIC', 'WA')
    keep_years <- 2014:2017
    df <- read.table(data_file, header = TRUE, as.is = TRUE)

    df$SurveyWeek <- as.Date(df$SurveyWeek)
    df$OverlapDate <- as.Date(df$OverlapDate)
    df <- df[df$StateName %in% keep_states & df$Year %in% keep_years, ]

    priors <- df[df$Prior & df$Year == 2017, ]

    p <- ggplot(df, aes(OverlapDate, Expected)) +
        geom_ribbon(mapping = aes(ymin = LowerCI, ymax = UpperCI,
                                  fill = factor(Year)),
                    alpha = 0.25) +
        geom_line(mapping = aes(colour = factor(Year)),
                  size = 1) +
        geom_hline(data = priors,
                   mapping = aes(yintercept = Expected),
                   linetype = 'dashed') +
        scale_colour_brewer('Year', palette = 'Dark2') +
        scale_fill_brewer('Year', palette = 'Dark2') +
        xlab(NULL) +
        ylab(expression(P(Test ~ "|" ~ ILI))) +
        expand_limits(y = max(df$UpperCI)) +
        facet_wrap(~ StateName, scale = 'free') +
        guides(colour = guide_legend(nrow = 1),
               fill = guide_legend(nrow = 1)) +
        theme_rgm(base.size = 12, key.box = 1.0) +
        theme(legend.text = element_text(vjust = 0.5, hjust = 0,
                                         margin = margin(l = 4, r = 12)),
              legend.position = 'top',
              legend.justification = c(0.5, 0),
              legend.spacing.x = unit(0.25, 'char'))

    cat('Writing', plot_file, '...')
    CairoPDF(plot_file, bg = 'transparent', width = plot_w, height = plot_h)
    print(p)
    invisible(dev.off())
    cat('\n')

    return(0)
}


##
## Only call main() if this script is being run from the command-line.
##
if (! interactive()) {
    file.arg <- grep('^--file=', commandArgs(FALSE), value = TRUE)
    file.path <- substring(file.arg, 8)
    file.regex <- paste0('^(|.*/)', SCRIPT)
    if (grepl(file.regex, file.path)) {
        quit(status = main(args = commandArgs(TRUE)))
    }
}
